@@ -44,7 +44,7 @@ class deviceModule(ranaModule):
     return the preferred application window size in pixels
     """
     # we'll use VGA as a default value
-    return((640,480))
+    return 640,480
 
   def startInFullscreen(self):
     """weather or not to start modRana in fullscreen
@@ -81,6 +81,13 @@ class deviceModule(ranaModule):
     them out of view - the user might want that the window redraws on the dashboard or not"""
     return False
 
+  def getSupportedGUIModuleIds(self):
+    """
+    supported GUI module IDs, ordered by preference from left to right
+    (the most-preferred should be on the left)
+    """
+    return ["GTK", "QML"] # as default try GTK first and then QML
+
   def handlesLocation(self):
     """report whether the device module handles position updates by itself"""
     return False
@@ -191,7 +198,7 @@ class deviceModule(ranaModule):
 
   def openUrl(self, url):
     """
-    open a URL
+    open an URL
     """
     pass
 
